@@ -354,6 +354,7 @@ def dependencies_met():
 
     # check python deps
 # pylint: disable=C0415
+
     # python-magic
     name = 'python-magic'
     err = f'missing python module \"{name}\"'
@@ -372,7 +373,7 @@ def dependencies_met():
         from docopt import docopt
         assert docopt
     except ImportError as exc:
-        raise Exception(err) from exc
+        raise UnmetDependency(err) from exc
 
     # jinja2
     name = 'jinja2'
@@ -381,7 +382,7 @@ def dependencies_met():
         import jinja2
         assert jinja2
     except ImportError as exc:
-        raise Exception(err) from exc
+        raise UnmetDependency(err) from exc
 
     # ruamel.yaml
     name = 'ruamel.yaml'
@@ -390,7 +391,7 @@ def dependencies_met():
         from ruamel.yaml import YAML
         assert YAML
     except ImportError as exc:
-        raise Exception(err) from exc
+        raise UnmetDependency(err) from exc
 
     # toml
     name = 'toml'
@@ -399,7 +400,7 @@ def dependencies_met():
         import toml
         assert toml
     except ImportError as exc:
-        raise Exception(err) from exc
+        raise UnmetDependency(err) from exc
 
     # distro
     name = 'distro'
@@ -408,7 +409,7 @@ def dependencies_met():
         import distro
         assert distro
     except ImportError as exc:
-        raise Exception(err) from exc
+        raise UnmetDependency(err) from exc
 
 # pylint: enable=C0415
 
@@ -495,17 +496,31 @@ def debug_dict(title, elems, debug):
 
 
 def check_version():
-    """check dotdrop version on github and compare with current"""
+    """
+    get dotdrop latest version on github
+    compare with "version"
+    and emit warning in case new version is available
+    """
     url = 'https://api.github.com/repos/deadc0de6/dotdrop/releases/latest'
-    req = requests.get(url, timeout=1)
-    if not req:
+    try:
+        req = requests.get(url, timeout=1)
+    except requests.exceptions.RequestException:
+        # request failed
         return
+    if not req:
+        # request failed
+        return
+    if req.status_code != 200:
+        # request failed
+        return
+    # get json
     try:
         latest = req.json()['name']
     except json.decoder.JSONDecodeError:
         return
     except ValueError:
         return
+    # compare
     if latest.startswith('v'):
         latest = latest[1:]
     if version.parse(VERSION) < version.parse(latest):
